var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var events_1 = require('events');
var equal_1 = require('./equal');
var clone_1 = require('./clone');
var Listener = (function (_super) {
    __extends(Listener, _super);
    function Listener(parent, prop) {
        var _this = this;
        if (parent === void 0) { parent = null; }
        if (prop === void 0) { prop = null; }
        _super.call(this);
        this.parent = parent;
        this.prop = prop;
        this.watchers = {};
        this.data = undefined;
        this._data = undefined;
        Object.defineProperty(this, 'data', {
            get: function () {
                return clone_1.default(_this._data);
            },
            set: function () {
                throw new Error('Readonly property');
            }
        });
    }
    //Update this listeners data. Call this only on the top level listener
    Listener.prototype.update = function (obj, fromParent) {
        var _this = this;
        if (fromParent === void 0) { fromParent = false; }
        if (fromParent || !this.parent) {
            //Propagate down
            var oldObj = this._data;
            this._data = obj;
            //Only emit a change if anything was modified
            if (!equal_1.default(oldObj, this._data)) {
                this.emit('change', this._data);
                Object.keys(this.watchers).forEach(function (prop) {
                    _this.updateChild(prop);
                });
            }
        }
        else {
            //Propagate up
            if (arguments.length === 0) {
                this.parent.updateProp(this.prop);
            }
            else {
                this.parent.updateProp(this.prop, obj);
            }
        }
    };
    //Update a single property
    Listener.prototype.updateProp = function (prop, obj) {
        if (typeof this._data !== 'object') {
            throw new Error('Cannot update property on non-object');
        }
        //Clone the object to avoid weird shit happening
        var newObj = this.data;
        if (arguments.length === 2) {
            newObj[prop] = obj;
        }
        else {
            delete newObj[prop];
        }
        //Update ourselves and therefore propagate further up
        this.update(newObj);
    };
    //Update a child instance
    Listener.prototype.updateChild = function (prop) {
        //update all children, and if we do not have an object, update them with undefined
        if (typeof this._data === 'object' && this._data !== null) {
            this.watchers[prop].update(this._data[prop], true);
        }
        else {
            this.watchers[prop].update(undefined, true);
        }
    };
    //Create a child instance. Basically watch a part of the main object. Pass a path like 'some.path.to.property'
    Listener.prototype.child = function (path) {
        if (!path)
            return this;
        if (path[0] === '<') {
            //We want to access the parent, so fetch the child from the parent
            return this.parent.child(path.substr(1));
        }
        else {
            var parts = path.split('.');
            var prop = parts.shift();
            //If we already have a watcher, dont create a new one
            this.watchers[prop] = this.watchers[prop] || new Listener(this, prop);
            this.updateChild(prop);
            if (parts.length > 0) {
                //We have a property chain, so access a child of a child of a child etc.
                return this.watchers[prop].child(parts.join('.'));
            }
            else {
                return this.watchers[prop];
            }
        }
    };
    //Utility function to allow passing a path and supplying the parent listener later
    //Useful in certain situations where you only know your path ahead of time
    Listener.defer = function (pth) {
        return function (ctx) {
            return ctx.child(pth);
        };
    };
    return Listener;
})(events_1.EventEmitter);
module.exports = Listener;
